package Task::Catmandu;

use strict;
use warnings;

our $VERSION = '0.1';

1;

__END__

=encoding utf-8

=for stopwords

=head1 NAME

Task::Catmandu - Catmandu bundle

=head1 SYNOPSIS

  cpanm --interactive Task::Catmandu

=head1 AUTHOR

Nicolas Steenlant <lt>nicolas.steenlant@ugent.be<gt>

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 SEE ALSO

L<http://librecat.org/>

=cut
